@@ -3,8 +3,6 @@
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
 use File::Temp qw/tempdir/;
 
 use Verby::Dispatcher;
@@ -12,14 +10,6 @@ use Verby::Step::Closure qw/step/;
 use Verby::Config::Data;
 use File::Basename;
 
-my $l4pconf = <<L4P;
-	log4perl.rootLogger 			= INFO, term
-
-	log4perl.appender.term			= Log::Log4perl::Appender::ScreenColoredLevels
-	log4perl.appender.term.layout	= Log::Log4perl::Layout::SimpleLayout::Multiline
-L4P
-Log::Log4perl::init(\$l4pconf);
-
 my $cfg = Verby::Config::Data->new;
 %{ $cfg->data } = (
 	project_root => my $out_dir = tempdir(CLEANUP => 1),
@@ -77,11 +67,11 @@ Yuval Kogman, E<lt>nothingmuch@woobling.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005 by Infinity Interactive, Inc.
+Copyright 2005-2008 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
-=cut
\ No newline at end of file
+=cut
