@@ -70,9 +70,6 @@ sub sigchld_handler {
 
 	$heap->{c}->logger->debug("sigchild $pid");
 
-	my $wheel = delete $heap->{pid_to_wheel}{$pid};
-	delete $heap->{id_to_wheel}{ $wheel->ID };
-
 	$kernel->refcount_decrement( $session->ID, 'child_processes' );
 
 	$heap->{program_exit} = $child_error;
@@ -176,11 +173,6 @@ sub poe_stop {
 
 	$heap->{c}->logger->info("Wheel::Run subsession closing");
 
-	if ( scalar keys %{ $heap->{pid_to_wheel} } ) {
-		require Data::Dumper;
-		die "AAAAAAAHHH Running proces!" . Data::Dumper::Dumper($heap);
-	}
-
 	my $c = $heap->{c};
 
 	$c->command_line( $heap->{cli} ) if exists $heap->{cli};
